@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store::SQL;
-our $VERSION = '1.20140623'; # VERSION
+our $VERSION = '1.20140711'; # VERSION
 use strict;
 use warnings;
 
@@ -283,8 +283,8 @@ LEFT JOIN domain fd ON r.from_domain_id=fd.id
 WHERE rr.count IS NULL
   AND rr.report_id IS NOT NULL
   AND r.end < ?
-GROUP BY rid
-ORDER BY rid
+GROUP BY r.id
+ORDER BY r.id
 LIMIT 1
 EO_TODO_QUERY
 ;
@@ -501,7 +501,7 @@ sub insert_rr_reason {
     my ( $self, $row_id, $type, $comment ) = @_;
     return $self->query(
         'INSERT INTO report_record_reason (report_record_id, type, comment) VALUES (?,?,?)',
-        [ $row_id, $type, $comment || '' ]
+        [ $row_id, $type, ($comment || '') ]
     );
 }
 
@@ -722,7 +722,7 @@ Mail::DMARC::Report::Store::SQL - store and retrieve reports from a SQL RDBMS
 
 =head1 VERSION
 
-version 1.20140623
+version 1.20140711
 
 =head1 DESCRIPTION
 
